@@ -35,12 +35,14 @@ static const gchar duh_custom_title_format[] = "${file-name}${?title: - ${title}
 static gint output_frequency;
 static const gint output_frequencies[]={4000, 8000, 11025, 22050, 44100, 48000, 64000, 96000};
 static GtkWidget *prefs;
+static GMutex *dumblock;
 
 gchar *fmts[] = { "mod", "s3m", "it", "xm", "duh", NULL };
 
 InputPlugin duh_ip = {
     .description = "DUMB Plugin " VERSION,
     .init = duh_init,
+    .cleanup = duh_cleanup,
     .about = duh_about,
     .configure = duh_configure,
     .play_file = play_file,
@@ -82,8 +84,15 @@ static void duh_init(void)
 	 *  and not when VFS puts them to a memory location first   */
 	
 	dumb_it_max_to_mix = 256;
+	
+	dumblock = g_mutex_new();
 }
 
+static void duh_cleanup(void)
+{
+	g_mutex_free(dumblock);
+}	
+
 static int is_our_file_from_vfs(gchar *filename, VFSFile *file)
 {
 	gchar magic[4];
@@ -189,9 +198,11 @@ static gint duh_universal_load_vfs(DUH **duh, const char *filename, VFSFile *ext
 
 	for (count = 0; count < total_count; count++) {
 		if (uniread[count].testmask & testmask) {
+			g_mutex_lock(dumblock);
 			filedumb = dumbfile_open_memory(filemap, readsize);
 			*duh = uniread[count].read(filedumb);
 			dumbfile_close(filedumb);
+			g_mutex_unlock(dumblock);
 			if (*duh) {
 				ext_index = count;
 				break;
